<?php
/**
* Plugin Name: Inside Posts
* Plugin Version: 0.3
* Mybb Compatibility: 1.6x
* Author: mybbromania
* Copyright:  2008-2011 mybbromania
* Description: Display custom content inside posts
*
* This program is free software: you can redistribute it and/or 
* modify it under the terms of the GNU General Public License as 
* published by the Free Software Foundation, either version 3 of 
* the License, or (at your option) any later version.
* This program is distributed in the hope that it will be useful, 
* but WITHOUT ANY WARRANTY; without even the implied warranty 
* of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
* See the GNU General Public License for more details.
* http://www.gnu.org/licenses/
**/

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

// Plugin hook(s)
$plugins->add_hook("pre_output_page", "insideposts_postbit");
$plugins->add_hook("postbit", "insideposts_postbit");

// Plugin info
function insideposts_info()
{
	return array(
		"name"			=> "Inside Posts",
		"description"	=> "Display custom content inside posts",
		"website"		=> "http://mods.mybb.com",
		"author"		=> "mybbromania",
		"authorsite"	=> "http://community.mybb.com/user-13352.html",
		"version"		=> "0.3",
		"guid"			=> "8133a62d86d21d8234761974b169533e",
		"compatibility" => "16*"
	);

}

// Activate plugin
function insideposts_activate()
{
	global $db, $mybb;

	$insideposts_group = array(
		"gid"			=> "NULL",
		"name"			=> "insideposts_settings",
		"title" 		=> "Inside Posts",
		"description"	=> "This section allows you to set the global preferences for Inside Posts plugin.",
		"disporder"		=> "100",
		"isdefault"		=> "no",
	);
	$db->insert_query("settinggroups", $insideposts_group);
	$gid = $db->insert_id();
	
    $insideposts_setting_1 = array(
        "sid"			=> "NULL",
        "name"			=> "insideposts_display",
        "title"			=> "Display",
        "description"	=> "Select how do you want to display your custom content Inside Posts:",
        "optionscode"	=> "radio\r\n1=Inside first post \r\n2=Inside all posts",
        "value"			=> "1",
        "disporder"		=> "2",
        "gid"			=> intval($gid),
        );

    $insideposts_setting_2 = array(
        "sid"			=> "NULL",
        "name"			=> "insideposts_position",
        "title"			=> "Position",
        "description"	=> "Select position for custom content Inside Posts:",
        "optionscode"	=> "radio\r\n1=Before post content \r\n2=After post content",
        "value"			=> "1",
        "disporder"		=> "3",
        "gid"			=> intval($gid),
        );
		
    $insideposts_setting_3 = array(
        "sid"			=> "NULL",
        "name"			=> "insideposts_align",
        "title"			=> "Alignment",
        "description"	=> "Select alignment for custom content Inside Posts:",
        "optionscode"	=> "radio\r\n1=Left \r\n2=Center \r\n3=Right",
        "value"			=> "2",
        "disporder"		=> "4",
        "gid"			=> intval($gid),
        );
		
    $insideposts_setting_4 = array(
        "sid"			=> "NULL",
        "name"			=> "insideposts_content",
        "title"			=> "Content",
        "description"	=> "Insert the custom content here to be displayed Inside Posts (HTML is acceptable):",
        "optionscode"	=> "textarea",
        "value"			=> "",
        "disporder"		=> "5",
        "gid"			=> intval($gid),
        );

    $insideposts_setting_5 = array(
        "sid"			=> "NULL",
        "name"			=> "insideposts_who",
        "title"			=> "Usergroups",
        "description"	=> "Who do you want to see your custom content Inside Posts ?",
        "optionscode"	=> "radio\r\n1=Only guests \r\n2=Only members  \r\n3=All guests and members",
        "value"			=> "2",
        "disporder"		=> "6",
        "gid"			=> intval($gid),
        );
	
	$db->insert_query("settings", $insideposts_setting_1);
	$db->insert_query("settings", $insideposts_setting_2);
	$db->insert_query("settings", $insideposts_setting_3);
	$db->insert_query("settings", $insideposts_setting_4);
	$db->insert_query("settings", $insideposts_setting_5);
	
	// Rebuild settings
    rebuildsettings();
}

// Deactivate plugin
function insideposts_deactivate()
{
	global $db, $mybb;

	$db->query("DELETE FROM ".TABLE_PREFIX."settinggroups WHERE name='insideposts_settings'");
	$db->query("DELETE FROM ".TABLE_PREFIX."settings WHERE name='insideposts_display'");
	$db->query("DELETE FROM ".TABLE_PREFIX."settings WHERE name='insideposts_position'");
	$db->query("DELETE FROM ".TABLE_PREFIX."settings WHERE name='insideposts_align'");
	$db->query("DELETE FROM ".TABLE_PREFIX."settings WHERE name='insideposts_content'");
	$db->query("DELETE FROM ".TABLE_PREFIX."settings WHERE name='insideposts_who'");
	
	// Rebuild settings
    rebuildsettings();
}

// Run plugin
function insideposts_postbit(&$post)
{
	global $settings, $mybb, $postcounter, $theme;
	
	$insideposts_content = $mybb->settings['insideposts_content'];
	$insideposts_top_left = "<div align=\"left\">".$insideposts_content."</div>{$post['message']}";
	$insideposts_top_center = "<div align=\"center\">".$insideposts_content."</div>{$post['message']}";
	$insideposts_top_right = "<div align=\"right\">".$insideposts_content."</div>{$post['message']}";
	$insideposts_bottom_left = "{$post['message']}<div align=\"left\">".$insideposts_content."</div>";
	$insideposts_bottom_center = "{$post['message']}<div align=\"center\">".$insideposts_content."</div>";
	$insideposts_bottom_right = "{$post['message']}<div align=\"right\">".$insideposts_content."</div>";
	
	if ($mybb->settings['insideposts_who'] == "1" && $mybb->user['uid'] == '')
	{
		if ($mybb->settings['insideposts_display'] == "2")
		{
			if ($mybb->settings['insideposts_position'] == "1") 
			{
				if ($mybb->settings['insideposts_align'] == "1") {$post['message'] = $insideposts_top_left;}
				elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_top_center;}
				else {$post['message'] = $insideposts_top_right;}
			}
			else
			{
				if ($mybb->settings['insideposts_align'] == "1")	{$post['message'] = $insideposts_bottom_left;}
				elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_bottom_center;}
				else {$post['message'] = $insideposts_bottom_right;}
			}	
		}
		elseif ($mybb->settings['insideposts_display'] == "1" && $postcounter == "1")
		{
			if ($mybb->settings['insideposts_position'] == "1") 
			{
				if ($mybb->settings['insideposts_align'] == "1") {$post['message'] = $insideposts_top_left;}
				elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_top_center;}
				else {$post['message'] = $insideposts_top_right;}
			}
			else
			{
				if ($mybb->settings['insideposts_align'] == "1")	{$post['message'] = $insideposts_bottom_left;}
				elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_bottom_center;}
				else {$post['message'] = $insideposts_bottom_right;}
			}	
		}
	}
	elseif ($mybb->settings['insideposts_who'] == "2" && $mybb->user['uid'] != '')
	{
		if ($mybb->settings['insideposts_display'] == "2")
		{
			if ($mybb->settings['insideposts_position'] == "1") 
			{
				if ($mybb->settings['insideposts_align'] == "1") {$post['message'] = $insideposts_top_left;}
				elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_top_center;}
				else {$post['message'] = $insideposts_top_right;}
			}
			else
			{
				if ($mybb->settings['insideposts_align'] == "1")	{$post['message'] = $insideposts_bottom_left;}
				elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_bottom_center;}
				else {$post['message'] = $insideposts_bottom_right;}
			}	
		}
		elseif ($mybb->settings['insideposts_display'] == "1" && $postcounter == "1")
		{
			if ($mybb->settings['insideposts_position'] == "1") 
			{
				if ($mybb->settings['insideposts_align'] == "1") {$post['message'] = $insideposts_top_left;}
				elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_top_center;}
				else {$post['message'] = $insideposts_top_right;}
			}
			else
			{
				if ($mybb->settings['insideposts_align'] == "1")	{$post['message'] = $insideposts_bottom_left;}
				elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_bottom_center;}
				else {$post['message'] = $insideposts_bottom_right;}
			}	
		}
	}
	else
	{
		if ($mybb->settings['insideposts_who'] == "3")
		{
			if ($mybb->settings['insideposts_display'] == "2")
			{
				if ($mybb->settings['insideposts_position'] == "1") 
				{
					if ($mybb->settings['insideposts_align'] == "1") {$post['message'] = $insideposts_top_left;}
					elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_top_center;}
					else {$post['message'] = $insideposts_top_right;}
				}
				else
				{
					if ($mybb->settings['insideposts_align'] == "1")	{$post['message'] = $insideposts_bottom_left;}
					elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_bottom_center;}
					else {$post['message'] = $insideposts_bottom_right;}
				}	
			}
			elseif ($mybb->settings['insideposts_display'] == "1" && $postcounter == "1")
			{
				if ($mybb->settings['insideposts_position'] == "1") 
				{
					if ($mybb->settings['insideposts_align'] == "1") {$post['message'] = $insideposts_top_left;}
					elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_top_center;}
					else {$post['message'] = $insideposts_top_right;}
				}
				else
				{
					if ($mybb->settings['insideposts_align'] == "1")	{$post['message'] = $insideposts_bottom_left;}
					elseif ($mybb->settings['insideposts_align'] == "2") {$post['message'] = $insideposts_bottom_center;}
					else {$post['message'] = $insideposts_bottom_right;}
				}	
			}
		}
	}
}
?>